"use strict";
function _export(target, all) {
    for(var name in all)Object.defineProperty(target, name, {
        enumerable: true,
        get: all[name]
    });
}
_export(exports, {
    runPostTargets: function() {
        return runPostTargets;
    },
    normalizePostTargets: function() {
        return normalizePostTargets;
    },
    withPostTargets: function() {
        return withPostTargets;
    }
});
const _devkit = require("@nrwl/devkit");
const _utilities = require("@nx-expand/utilities");
const _lodash = require("lodash");
function _extends() {
    _extends = Object.assign || function(target) {
        for(var i = 1; i < arguments.length; i++){
            var source = arguments[i];
            for(var key in source){
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key];
                }
            }
        }
        return target;
    };
    return _extends.apply(this, arguments);
}
async function runPostTargets(targets, context, result) {
    // load the extra env vars
    (0, _lodash.assign)(process.env, (0, _lodash.mapValues)(result.env, (value)=>{
        return value == null ? void 0 : value.toString();
    }));
    const variables = _extends({}, result, {
        env: process.env,
        // cop-out with the type coercion, but failing to see how to do it right 🤷‍♂️
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        context: context
    });
    const postTargets = normalizePostTargets(targets);
    for (const postTarget of postTargets){
        const targetString = (0, _devkit.targetToTargetString)(postTarget.target);
        _devkit.logger.info(`Running post-target "${targetString}".`);
        try {
            await runPostTarget(postTarget, context, variables);
        } catch (error) {
            if (error instanceof Error) {
                _devkit.logger.error(`An error occured while running post-target "${targetString}": ${error.stack}}`);
            }
            throw error;
        }
    }
}
async function runPostTarget(postTarget, context, variables = {}) {
    const targetOptions = (0, _devkit.readTargetOptions)(postTarget.target, context);
    const overrides = (0, _utilities.expandParametersInObject)(_extends({}, targetOptions, postTarget.overrides), variables);
    for await (const { success  } of (await (0, _devkit.runExecutor)(postTarget.target, overrides, context))){
        if (!success) {
            const targetString = (0, _devkit.targetToTargetString)(postTarget.target);
            throw new Error(`Something went wrong with post-target "${targetString}".`);
        }
    }
}
function normalizePostTargets(targets) {
    return targets.map((target)=>{
        if (typeof target === 'string') {
            return {
                target: (0, _devkit.parseTargetString)(target)
            };
        }
        if ('project' in target) {
            return {
                target
            };
        }
        return _extends({}, target, {
            target: typeof target.target === 'string' ? (0, _devkit.parseTargetString)(target.target) : target.target
        });
    });
}
async function unwrapExecutorIterator(input) {
    let lastResult = {
        success: false
    };
    for await (const result of input){
        lastResult = result;
        if (!result.success) break;
    }
    return lastResult;
}
function withPostTargets(executor) {
    return async (options, context)=>{
        let result;
        try {
            const promiseOrIterable = executor(options, context);
            result = 'then' in promiseOrIterable ? await promiseOrIterable : await unwrapExecutorIterator(promiseOrIterable);
        } catch (e) {
            var _options_postTargets;
            var _options_postTargets_onFailure;
            // unexpected error, so no metadata is prepared for us
            // TODO: make some error metadata available, maybe in a separate HOC
            await runPostTargets((_options_postTargets_onFailure = (_options_postTargets = options.postTargets) == null ? void 0 : _options_postTargets.onFailure) != null ? _options_postTargets_onFailure : [], context, {
                success: false
            });
            throw e;
        }
        if (result.success) {
            var _options_postTargets1;
            var _options_postTargets_onSuccess;
            await runPostTargets((_options_postTargets_onSuccess = (_options_postTargets1 = options.postTargets) == null ? void 0 : _options_postTargets1.onSuccess) != null ? _options_postTargets_onSuccess : [], context, result);
        } else {
            var _options_postTargets2;
            var _options_postTargets_onFailure1;
            await runPostTargets((_options_postTargets_onFailure1 = (_options_postTargets2 = options.postTargets) == null ? void 0 : _options_postTargets2.onFailure) != null ? _options_postTargets_onFailure1 : [], context, result);
        }
        return result;
    };
}

//# sourceMappingURL=post-targets.js.map